#!/usr/bin/perl -w
use strict;

# This script adjusts the Makefiles
# It is much easier to set the library paths and compilers
# here than to do it in the makefiles themselves.
# I could probably do this with automake, but it seemed like overkill
# for so few options.
# John C. Vernaleo (vernaleo@astro.umd.edu)
# initially added 09/28/2004
# last modified 09/19/2005

#set true if compiling on borg, false otherwise
my $borg=0;
#set true for locutus
my $locutus=0;
#set true if compiling on ganon, false otherwise
my $ganon=0;
#set true for intel compilers, false for portland group.
my $intel=0;
#set true for gnu compilers, false for anything else
my $gnu=1;
#set true for lam, false for mpich
my $lam=1;
#set true for OSX (Darwin)
my $osx=0;

my $opt;
my $optpp;
my $fc;
my $cc;
my $mpipath;
my $mpiopts;
my $mpichpath;
my $hdfpath;
my $lampath;
my $laminc;
my $mpichinc;
my $mpiinc;
my $mpilib;
my $lamopts="-llamf77mpi -lmpi -llam";
my $mpichopts="-lpmpich -lmpich -lpmpich -lmpich";
my $extra=" -lnsl -lutil";

if($borg){
    $mpichpath="/home/vernaleo/mpich_intel";
    $lampath="/net/lam";
    $laminc=" ";
    $hdfpath="-L/home/vernaleo/hdf/lib";
}else{
    $mpichpath="/n/thales2/vernaleo/mpich_intel";
    $lampath="/n/thales2/vernaleo/lam";
    $laminc="-I$lampath"."/include";
    $hdfpath="-L/n/thales2/vernaleo/hdf/lib";
}
if($ganon){
    $mpichpath="";
    $lampath="";
    $laminc="";
    $hdfpath="";
}
if($locutus){
    $mpichpath="/home/vernaleo/mpich_intel";
    $lampath=" ";
    $laminc=" ";
    $hdfpath="-L/home/vernaleo/hdf/lib";
}

if($intel){
    $fc="ifort -static";
    $cc="icc";
    $opt="-O2 -axW";
    $optpp="-DLINUX";
}else{
    $opt="-O2";
    $fc="pgf77";
    $cc="pgcc";
    $optpp="-DLINUX";
}
if($gnu){
    $fc="g77 -static -Wno-globals ";
    $cc="gcc";
    $opt="-O2";
    $optpp="";
}
if($osx){
    $fc="g77 -Wno-globals ";
    $cc="gcc";
    $opt="-O2";
    $optpp="";
    $lampath="/sw";
    $laminc="-I$lampath"."/include";
    $hdfpath="-L/sw/lib";
    $extra="";
}  

if($lam){
    $mpipath=$lampath;
    $mpiopts=$lamopts;
    $mpiinc=$laminc;
    $mpilib="-L$lampath"."/lib";
}else{
    $mpipath=$mpichpath;
    $mpiopts=$mpichopts;
    $mpiinc=$mpichinc;
    $mpilib="-L$mpichpath"."/lib";
}

@ARGV="Makefile";
$^I="~";

while(<>){
    s/ZMP_FC[\s]+=.*/ZMP_FC     = $fc/;
    s/ZMP_CC[\s]+=.*/ZMP_CC     = $cc/;
    s/ZMP_CPP[\s]+=.*/ZMP_CPP    = \${ZMP_FC} $optpp -DTLB=128 -DUNROLL_I=4 -DUNROLL_J=4 -DUNROLL_K=4/;
    s/ZMP_LIB[\s]+=.*/ZMP_LIB    = $hdfpath $mpilib -ldl$extra -lmfhdf -ldf -ljpeg -lz $mpiopts -lpthread/;
    s/ZMP_OPTS3[\s]+=.*/ZMP_OPTS3  = -c $opt -I\/usr\/include $mpiinc/;
    s/ZMP_OPTS0[\s]+=.*/ZMP_OPTS0  = -c -O0 -I\/usr\/include $mpiinc/;
    s/ZMP_LDR[\s]+=.*/ZMP_LDR    = \${ZMP_FC} $opt $mpiinc/;
    print;
}


@ARGV="../pp/Makefile";
$^I="~";

while(<>){
    s/ZMP_FC[\s]+=.*/ZMP_FC     = $fc/;
    s/ZMP_CC[\s]+=.*/ZMP_CC     = $cc/;
    s/ZMP_LIB[\s]+=.*/ZMP_LIB    = $hdfpath $mpilib -ldl$extra -lmfhdf -ldf -ljpeg -lz $mpiopts -lpthread/;
    s/ZMP_OPTS[\s]+=.*/ZMP_OPTS   = -c -O3 -I\/usr\/include $mpiinc/;
    s/ZMP_LDR[\s]+=.*/ZMP_LDR    = \${ZMP_FC} -O3 $mpiinc/;
    s/ZMP_CPP[\s]+=.*/ZMP_CPP    = \${ZMP_FC} $optpp -DTLB=128 -DUNROLL_I=4 -DUNROLL_J=4 -DUNROLL_K=4/;
    print;
   }



